@@ -382,6 +382,12 @@ impl MainWindow {
             }
         });
 
+        self.window.on_open_url({
+            move |url: SharedString| {
+                opener::open(url.as_str()).ok();
+            }
+        });
+
         self.window.on_recheck_similarities({
             // Browse source was clicked, select new path
             let window_weak = self.window.as_weak();
@@ -556,7 +562,7 @@ pub fn get_item_text(index: usize, item_list: &ItemList) -> SharedString {
     } else {
         ""
     };
-    SharedString::from(item.to_string() + event_str)
+    SharedString::from(item.to_string() + " " + event_str)
 }
 
 /// Commits the item list in a background thread
